@@ -19,7 +19,7 @@ from datetime import datetime
 from typing import List, Optional
 
 from pydantic import BaseModel, Field, validator
-from sqlalchemy import Column, DateTime, Float, ForeignKey, Integer, String
+from sqlalchemy import Column, DateTime, Float, ForeignKey, Index, Integer, String
 from sqlalchemy.orm import declarative_base, relationship
 
 from nowcasting_forecast.database.utils import convert_to_camelcase, datetime_must_have_timezone
@@ -73,7 +73,7 @@ class Location(EnhancedBaseModel):
     """Location that the forecast is for"""
 
     label: str = Field(..., description="")
-    gsp_id: Optional[int] = Field(None, description="The Grid Supply Point (GSP) id")
+    gsp_id: Optional[int] = Field(None, description="The Grid Supply Point (GSP) id", index=True)
     gsp_name: Optional[str] = Field(None, description="The GSP name")
     gsp_group: Optional[str] = Field(None, description="The GSP group name")
     region_name: Optional[str] = Field(None, description="The GSP region name")
@@ -103,9 +103,11 @@ class ForecastValueSQL(Base, CreatedMixin):
     target_time = Column(DateTime(timezone=True))
     expected_power_generation_megawatts = Column(Float)
 
-    forecast_id = Column(Integer, ForeignKey("forecast.id"))
+    forecast_id = Column(Integer, ForeignKey("forecast.id"), index=True)
     forecast = relationship("ForecastSQL", back_populates="forecast_values")
 
+    Index("index_forecast_value", CreatedMixin.created_utc.desc())
+
 
 class ForecastValue(EnhancedBaseModel):
     """One Forecast of generation at one timestamp"""
@@ -144,6 +146,8 @@ class InputDataLastUpdatedSQL(Base, CreatedMixin):
 
     forecast = relationship("ForecastSQL", back_populates="input_data_last_updated")
 
+    Index("index_input_data", CreatedMixin.created_utc.desc())
+
 
 class InputDataLastUpdated(EnhancedBaseModel):
     """Information about the input data that was used to create the forecast"""
@@ -185,14 +189,18 @@ class ForecastSQL(Base, CreatedMixin):
 
     # many (forecasts) to one (location)
     location = relationship("LocationSQL", back_populates="forecast")
-    location_id = Column(Integer, ForeignKey("location.id"))
+    location_id = Column(Integer, ForeignKey("location.id"), index=True)
 
     # one (forecasts) to many (forecast_value)
     forecast_values = relationship("ForecastValueSQL", back_populates="forecast")
 
     # many (forecasts) to one (input_data_last_updated)
     input_data_last_updated = relationship("InputDataLastUpdatedSQL", back_populates="forecast")
-    input_data_last_updated_id = Column(Integer, ForeignKey("input_data_last_updated.id"))
+    input_data_last_updated_id = Column(
+        Integer, ForeignKey("input_data_last_updated.id"), index=True
+    )
+
+    Index("index_forecast", CreatedMixin.created_utc.desc())
 
 
 class Forecast(EnhancedBaseModel):
